function [N]=zeroslopes(X,deltat,threshold)
% Determines the vertex-edge incidence matrix by using the zero slopes
% method.
% -------------------------------------------------------------------------
% Input
%
% X: a n x m x p data structure of metabolite concentrations, with n the 
% number of time points, m the number of metabolites and p the number of 
% experiments in the data set. p=m, because each metabolite has to be 
% perturbed separately to use this method. Experiment i is obtained by
% perturbing metabolite i.
%
% deltat: time between two subsequent time points
% If the data are not evenly-sampled, use interpolation to get an equally
% sampled dataset.
%
% threshold: cut-off value. Initial slopes with absolute value smaller than 
% this value are treated as a zero.
% -------------------------------------------------------------------------
% Output
%
% N: vertex-edge incidence matrix
% -------------------------------------------------------------------------
% Reference
%
% Diana M. Hendrickx, Margriet M.W.B. Hendriks, Paul H.C. Eilers,
% Age K. Smilde and Huub C.J. Hoefsloot
% Reverse engineering of metabolic networks, a critical assessment.
% Mol. Biosyst., 2011, DOI: 10.1039/C0MB00083C
% -------------------------------------------------------------------------

% Author
% Diana M. Hendrickx, 04 January 2011
% -------------------------------------------------------------------------
% Version 
% 7.8.1.347 (R2009a)
% -------------------------------------------------------------------------

[n,m,p]=size(X);

for i=1:p
    for j=1:m
        if i==j
            N(j,i)=-1;
        elseif ((abs(X(2,j,i)-X(1,j,i)))/deltat)<threshold
            N(j,i)=0;
        else
            N(j,i)=1;
        end
    end
end

% -------------------------------------------------------------------------
% Copyright Notice
% This is a license to use and modify SOFTWARE & DATA
% produced by THE BIOSYSTEMS DATA ANALYSIS GROUP (BDA Group)
% OF THE UNIVERSITY OF AMSTERDAM
%
% If you use, modify or redistribute the SOFTWARE & DATA and/or
% your source modifications, you agree
%
% (i) to use the SOFTWARE & DATA and/or your source modifications
% solely as part of your research and not in any commercial
% product ;
%
% (ii) that the SOFTWARE & DATA and/or your source modifications
% will not be distributed for profit ;
%
% (iii) all copyright notices and this license note with the
% SOFTWARE & DATA are retained any redistribution of
% the SOFTWARE & DATA, or any portion thereof ;
%
% (iv) to indemnify, hold harmless, and defend the Biosystems
% Data Analysis Group of the University of Amsterdam
% from and against any claims or lawsuits that arise or
% result from the use of the SOFTWARE & DATA or your source
% modifications .
%
% (v) to properly reference the SOFTWARE & DATA when used in
% your research in any publication that may result from
% that research .
%
% Reserved Rights. The Biosystems Data Analysis Group of the
% University of Amsterdam retain title and all ownership
% rights to the SOFTWARE & DATA.
%
% Copyright 2010 Biosystems Data Analysis Group ;
% University of Amsterdam
%
            
    